@@ -30,7 +30,7 @@ def weights_shift(weight_mat=None, trading_delay = 1):
     weight_mat = weight_mat.shift(trading_delay)
     return weight_mat, last_predicted_weights
 
-def process_weights(w=None, df=None, s=None, n=None, low_bound=None, up_bound=None, weight_cutting_rate = 0.7, normalize = True , display=False, max_iteration = 50, trading_delay=1):
+def process_weights(w=None, df=None, s=None, n=None, low_bound=None, up_bound=None, weight_cutting_rate = 0.7, normalize = True , display=False, max_iteration = 50, trading_delay=1 , force_min_bound = False):
     """ Process weight to respect constraints.
     Parameters
     ----------
@@ -69,25 +69,29 @@ def process_weights(w=None, df=None, s=None, n=None, low_bound=None, up_bound=No
             continue
         # we override the bound constraint when the universe cardinality is too low
         local_up_bound = max(1./assets.sum(),up_bound)
+        if force_min_bound:
+            local_low_bound = min(1. / assets.sum(), low_bound)
+        else :
+            local_low_bound=low_bound
 
         weight_vect[assets, 0] = w[test_slice.start][assets]
 
         if normalize:
-            weight_vect = normalizeWeightsVector(weight_vect, assets, low_bound, local_up_bound)
+            weight_vect = normalizeWeightsVector(weight_vect, assets, local_low_bound, local_up_bound)
             counter=0
-            while not(weight_vect.max() <= local_up_bound and weight_vect.min() >= low_bound):
+            while not(weight_vect.max() <= local_up_bound and weight_vect.min() >= local_low_bound):
                 if counter>max_iteration:
                     break
-                weight_vect = normalizeWeightsVector(weight_vect,assets,low_bound,local_up_bound)
+                weight_vect = normalizeWeightsVector(weight_vect,assets,local_low_bound,local_up_bound)
                 counter=counter+1
         else:
             local_up_bound=1./assets.sum()
-            weight_vect = normalizeWeightsVector(weight_vect, assets, low_bound, local_up_bound)
+            weight_vect = normalizeWeightsVector(weight_vect, assets, local_low_bound, local_up_bound)
             counter=0
-            while not(weight_vect.max() <= local_up_bound and weight_vect.min() >= low_bound):
+            while not(weight_vect.max() <= local_up_bound and weight_vect.min() >= local_low_bound):
                 if counter>max_iteration:
                     break
-                weight_vect = normalizeWeightsVector(weight_vect,assets,low_bound,local_up_bound)
+                weight_vect = normalizeWeightsVector(weight_vect,assets,local_low_bound,local_up_bound)
                 counter=counter+1
 
         newValidWeights = None
@@ -104,9 +108,9 @@ def process_weights(w=None, df=None, s=None, n=None, low_bound=None, up_bound=No
         weight_mat.iloc[test_slice] = newValidWeights
 
         if display:
-            if w[test_slice.start].max() > local_up_bound or w[test_slice.start].min() < low_bound:
+            if w[test_slice.start].max() > local_up_bound or w[test_slice.start].min() < local_low_bound:
                 print('Invalid incoming weights')
-            if newValidWeights[0].max()> local_up_bound or newValidWeights[0].min() < low_bound:
+            if newValidWeights[0].max()> local_up_bound or newValidWeights[0].min() < local_low_bound:
                 print('Invalid outgoing weights')
                 print(newValidWeights[0].max())
                 print(newValidWeights[0].min())
